# forward-randalgo-muna

Problem it solves: Returns random algorithm question.
 
For the user login:
 
A user must sign up with the correct Email address, Username and Password of choice.
After signing up, the user must log in with the correct username and password.
After a successful log in, the user is prompted to choose the difficulty level of the questions.
After selection of difficulty level, a random algorithm question is print based on the difficulty level chosen.


